==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CAIssuerFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.util.function.Predicate;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CAIssuerFluent<A extends CAIssuerFluent<A>> extends BaseFluent<A>{
  public CAIssuerFluent() {
  }
  public CAIssuerFluent(CAIssuer instance) {
    instance = (instance != null ? instance : new CAIssuer());

    if (instance != null) {
      this.withCrlDistributionPoints(instance.getCrlDistributionPoints());
      this.withOcspServers(instance.getOcspServers());
      this.withSecretName(instance.getSecretName());
      this.withCrlDistributionPoints(instance.getCrlDistributionPoints());
      this.withOcspServers(instance.getOcspServers());
      this.withSecretName(instance.getSecretName());
    }
  }
  private List<String> crlDistributionPoints = new ArrayList<String>();
  private List<String> ocspServers = new ArrayList<String>();
  private String secretName;
  public A addToCrlDistributionPoints(int index,String item) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new ArrayList<String>();}
    this.crlDistributionPoints.add(index, item);
    return (A)this;
  }
  public A setToCrlDistributionPoints(int index,String item) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new ArrayList<String>();}
    this.crlDistributionPoints.set(index, item); return (A)this;
  }
  public A addToCrlDistributionPoints(java.lang.String... items) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new ArrayList<String>();}
    for (String item : items) {this.crlDistributionPoints.add(item);} return (A)this;
  }
  public A addAllToCrlDistributionPoints(Collection<String> items) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new ArrayList<String>();}
    for (String item : items) {this.crlDistributionPoints.add(item);} return (A)this;
  }
  public A removeFromCrlDistributionPoints(java.lang.String... items) {
    if (this.crlDistributionPoints == null) return (A)this;
    for (String item : items) { this.crlDistributionPoints.remove(item);} return (A)this;
  }
  public A removeAllFromCrlDistributionPoints(Collection<String> items) {
    if (this.crlDistributionPoints == null) return (A)this;
    for (String item : items) { this.crlDistributionPoints.remove(item);} return (A)this;
  }
  public List<String> getCrlDistributionPoints() {
    return this.crlDistributionPoints;
  }
  public String getCrlDistributionPoint(int index) {
    return this.crlDistributionPoints.get(index);
  }
  public String getFirstCrlDistributionPoint() {
    return this.crlDistributionPoints.get(0);
  }
  public String getLastCrlDistributionPoint() {
    return this.crlDistributionPoints.get(crlDistributionPoints.size() - 1);
  }
  public String getMatchingCrlDistributionPoint(Predicate<String> predicate) {
    for (String item: crlDistributionPoints) { if(predicate.test(item)){ return item;} } return null;
  }
  public boolean hasMatchingCrlDistributionPoint(Predicate<String> predicate) {
    for (String item: crlDistributionPoints) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCrlDistributionPoints(List<String> crlDistributionPoints) {
    if (crlDistributionPoints != null) {this.crlDistributionPoints = new ArrayList(); for (String item : crlDistributionPoints){this.addToCrlDistributionPoints(item);}} else { this.crlDistributionPoints = null;} return (A) this;
  }
  public A withCrlDistributionPoints(java.lang.String... crlDistributionPoints) {
    if (this.crlDistributionPoints != null) {this.crlDistributionPoints.clear(); _visitables.remove("crlDistributionPoints"); }
    if (crlDistributionPoints != null) {for (String item :crlDistributionPoints){ this.addToCrlDistributionPoints(item);}} return (A) this;
  }
  public boolean hasCrlDistributionPoints() {
    return crlDistributionPoints != null && !crlDistributionPoints.isEmpty();
  }
  public A addToOcspServers(int index,String item) {
    if (this.ocspServers == null) {this.ocspServers = new ArrayList<String>();}
    this.ocspServers.add(index, item);
    return (A)this;
  }
  public A setToOcspServers(int index,String item) {
    if (this.ocspServers == null) {this.ocspServers = new ArrayList<String>();}
    this.ocspServers.set(index, item); return (A)this;
  }
  public A addToOcspServers(java.lang.String... items) {
    if (this.ocspServers == null) {this.ocspServers = new ArrayList<String>();}
    for (String item : items) {this.ocspServers.add(item);} return (A)this;
  }
  public A addAllToOcspServers(Collection<String> items) {
    if (this.ocspServers == null) {this.ocspServers = new ArrayList<String>();}
    for (String item : items) {this.ocspServers.add(item);} return (A)this;
  }
  public A removeFromOcspServers(java.lang.String... items) {
    if (this.ocspServers == null) return (A)this;
    for (String item : items) { this.ocspServers.remove(item);} return (A)this;
  }
  public A removeAllFromOcspServers(Collection<String> items) {
    if (this.ocspServers == null) return (A)this;
    for (String item : items) { this.ocspServers.remove(item);} return (A)this;
  }
  public List<String> getOcspServers() {
    return this.ocspServers;
  }
  public String getOcspServer(int index) {
    return this.ocspServers.get(index);
  }
  public String getFirstOcspServer() {
    return this.ocspServers.get(0);
  }
  public String getLastOcspServer() {
    return this.ocspServers.get(ocspServers.size() - 1);
  }
  public String getMatchingOcspServer(Predicate<String> predicate) {
    for (String item: ocspServers) { if(predicate.test(item)){ return item;} } return null;
  }
  public boolean hasMatchingOcspServer(Predicate<String> predicate) {
    for (String item: ocspServers) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withOcspServers(List<String> ocspServers) {
    if (ocspServers != null) {this.ocspServers = new ArrayList(); for (String item : ocspServers){this.addToOcspServers(item);}} else { this.ocspServers = null;} return (A) this;
  }
  public A withOcspServers(java.lang.String... ocspServers) {
    if (this.ocspServers != null) {this.ocspServers.clear(); _visitables.remove("ocspServers"); }
    if (ocspServers != null) {for (String item :ocspServers){ this.addToOcspServers(item);}} return (A) this;
  }
  public boolean hasOcspServers() {
    return ocspServers != null && !ocspServers.isEmpty();
  }
  public String getSecretName() {
    return this.secretName;
  }
  public A withSecretName(String secretName) {
    this.secretName=secretName; return (A) this;
  }
  public boolean hasSecretName() {
    return this.secretName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CAIssuerFluent that = (CAIssuerFluent) o;
    if (!java.util.Objects.equals(crlDistributionPoints, that.crlDistributionPoints)) return false;

    if (!java.util.Objects.equals(ocspServers, that.ocspServers)) return false;

    if (!java.util.Objects.equals(secretName, that.secretName)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(crlDistributionPoints,  ocspServers,  secretName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (crlDistributionPoints != null && !crlDistributionPoints.isEmpty()) { sb.append("crlDistributionPoints:"); sb.append(crlDistributionPoints + ","); }
    if (ocspServers != null && !ocspServers.isEmpty()) { sb.append("ocspServers:"); sb.append(ocspServers + ","); }
    if (secretName != null) { sb.append("secretName:"); sb.append(secretName); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1alpha3-6.9.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CAIssuerFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.util.function.Predicate;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CAIssuerFluent<A extends CAIssuerFluent<A>> extends BaseFluent<A>{
  public CAIssuerFluent() {
  }
  
  public CAIssuerFluent(CAIssuer instance) {
    this.copyInstance(instance);
  }
  private List<String> crlDistributionPoints = new ArrayList<String>();
  private List<String> ocspServers = new ArrayList<String>();
  private String secretName;
  
  protected void copyInstance(CAIssuer instance) {
    instance = (instance != null ? instance : new CAIssuer());
  
    if (instance != null) {
        this.withCrlDistributionPoints(instance.getCrlDistributionPoints());
        this.withOcspServers(instance.getOcspServers());
        this.withSecretName(instance.getSecretName());
        this.withCrlDistributionPoints(instance.getCrlDistributionPoints());
        this.withOcspServers(instance.getOcspServers());
        this.withSecretName(instance.getSecretName());
      }
  }
  
  public A addToCrlDistributionPoints(int index,String item) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new ArrayList<String>();}
    this.crlDistributionPoints.add(index, item);
    return (A)this;
  }
  
  public A setToCrlDistributionPoints(int index,String item) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new ArrayList<String>();}
    this.crlDistributionPoints.set(index, item); return (A)this;
  }
  
  public A addToCrlDistributionPoints(java.lang.String... items) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new ArrayList<String>();}
    for (String item : items) {this.crlDistributionPoints.add(item);} return (A)this;
  }
  
  public A addAllToCrlDistributionPoints(Collection<String> items) {
    if (this.crlDistributionPoints == null) {this.crlDistributionPoints = new ArrayList<String>();}
    for (String item : items) {this.crlDistributionPoints.add(item);} return (A)this;
  }
  
  public A removeFromCrlDistributionPoints(java.lang.String... items) {
    if (this.crlDistributionPoints == null) return (A)this;
    for (String item : items) { this.crlDistributionPoints.remove(item);} return (A)this;
  }
  
  public A removeAllFromCrlDistributionPoints(Collection<String> items) {
    if (this.crlDistributionPoints == null) return (A)this;
    for (String item : items) { this.crlDistributionPoints.remove(item);} return (A)this;
  }
  
  public List<String> getCrlDistributionPoints() {
    return this.crlDistributionPoints;
  }
  
  public String getCrlDistributionPoint(int index) {
    return this.crlDistributionPoints.get(index);
  }
  
  public String getFirstCrlDistributionPoint() {
    return this.crlDistributionPoints.get(0);
  }
  
  public String getLastCrlDistributionPoint() {
    return this.crlDistributionPoints.get(crlDistributionPoints.size() - 1);
  }
  
  public String getMatchingCrlDistributionPoint(Predicate<String> predicate) {
    for (String item: crlDistributionPoints) { if(predicate.test(item)){ return item;} } return null;
  }
  
  public boolean hasMatchingCrlDistributionPoint(Predicate<String> predicate) {
    for (String item: crlDistributionPoints) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withCrlDistributionPoints(List<String> crlDistributionPoints) {
    if (crlDistributionPoints != null) {this.crlDistributionPoints = new ArrayList(); for (String item : crlDistributionPoints){this.addToCrlDistributionPoints(item);}} else { this.crlDistributionPoints = null;} return (A) this;
  }
  
  public A withCrlDistributionPoints(java.lang.String... crlDistributionPoints) {
    if (this.crlDistributionPoints != null) {this.crlDistributionPoints.clear(); _visitables.remove("crlDistributionPoints"); }
    if (crlDistributionPoints != null) {for (String item :crlDistributionPoints){ this.addToCrlDistributionPoints(item);}} return (A) this;
  }
  
  public boolean hasCrlDistributionPoints() {
    return crlDistributionPoints != null && !crlDistributionPoints.isEmpty();
  }
  
  public A addToOcspServers(int index,String item) {
    if (this.ocspServers == null) {this.ocspServers = new ArrayList<String>();}
    this.ocspServers.add(index, item);
    return (A)this;
  }
  
  public A setToOcspServers(int index,String item) {
    if (this.ocspServers == null) {this.ocspServers = new ArrayList<String>();}
    this.ocspServers.set(index, item); return (A)this;
  }
  
  public A addToOcspServers(java.lang.String... items) {
    if (this.ocspServers == null) {this.ocspServers = new ArrayList<String>();}
    for (String item : items) {this.ocspServers.add(item);} return (A)this;
  }
  
  public A addAllToOcspServers(Collection<String> items) {
    if (this.ocspServers == null) {this.ocspServers = new ArrayList<String>();}
    for (String item : items) {this.ocspServers.add(item);} return (A)this;
  }
  
  public A removeFromOcspServers(java.lang.String... items) {
    if (this.ocspServers == null) return (A)this;
    for (String item : items) { this.ocspServers.remove(item);} return (A)this;
  }
  
  public A removeAllFromOcspServers(Collection<String> items) {
    if (this.ocspServers == null) return (A)this;
    for (String item : items) { this.ocspServers.remove(item);} return (A)this;
  }
  
  public List<String> getOcspServers() {
    return this.ocspServers;
  }
  
  public String getOcspServer(int index) {
    return this.ocspServers.get(index);
  }
  
  public String getFirstOcspServer() {
    return this.ocspServers.get(0);
  }
  
  public String getLastOcspServer() {
    return this.ocspServers.get(ocspServers.size() - 1);
  }
  
  public String getMatchingOcspServer(Predicate<String> predicate) {
    for (String item: ocspServers) { if(predicate.test(item)){ return item;} } return null;
  }
  
  public boolean hasMatchingOcspServer(Predicate<String> predicate) {
    for (String item: ocspServers) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withOcspServers(List<String> ocspServers) {
    if (ocspServers != null) {this.ocspServers = new ArrayList(); for (String item : ocspServers){this.addToOcspServers(item);}} else { this.ocspServers = null;} return (A) this;
  }
  
  public A withOcspServers(java.lang.String... ocspServers) {
    if (this.ocspServers != null) {this.ocspServers.clear(); _visitables.remove("ocspServers"); }
    if (ocspServers != null) {for (String item :ocspServers){ this.addToOcspServers(item);}} return (A) this;
  }
  
  public boolean hasOcspServers() {
    return ocspServers != null && !ocspServers.isEmpty();
  }
  
  public String getSecretName() {
    return this.secretName;
  }
  
  public A withSecretName(String secretName) {
    this.secretName=secretName; return (A) this;
  }
  
  public boolean hasSecretName() {
    return this.secretName != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CAIssuerFluent that = (CAIssuerFluent) o;
    if (!java.util.Objects.equals(crlDistributionPoints, that.crlDistributionPoints)) return false;
  
    if (!java.util.Objects.equals(ocspServers, that.ocspServers)) return false;
  
    if (!java.util.Objects.equals(secretName, that.secretName)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(crlDistributionPoints,  ocspServers,  secretName,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (crlDistributionPoints != null && !crlDistributionPoints.isEmpty()) { sb.append("crlDistributionPoints:"); sb.append(crlDistributionPoints + ","); }
    if (ocspServers != null && !ocspServers.isEmpty()) { sb.append("ocspServers:"); sb.append(ocspServers + ","); }
    if (secretName != null) { sb.append("secretName:"); sb.append(secretName); }
    sb.append("}");
    return sb.toString();
  }
  

}
